@@ -10,15 +10,18 @@ book with unlimited questions that also e-mails submissions to the website owner
 package DemoGuestBook;
 require 5.004;
 
-# Copyright (c) 1999-2001, Darren R. Duncan. All rights reserved. This module is
-# free software; you can redistribute it and/or modify it under the same terms as
-# Perl itself.  However, I do request that this copyright information remain
-# attached to the file.  If you modify this module and redistribute a changed
-# version then please attach a note listing the modifications.
+# Copyright (c) 1999-2003, Darren R. Duncan.  All rights reserved.  This module
+# is free software; you can redistribute it and/or modify it under the same terms
+# as Perl itself.  However, I do request that this copyright information and
+# credits remain attached to the file.  If you modify this module and
+# redistribute a changed version then please attach a note listing the
+# modifications.  This module is available "as-is" and the author can not be held
+# accountable for any problems resulting from its use.
 
 use strict;
+use warnings;
 use vars qw($VERSION @ISA);
-$VERSION = '0.46';
+$VERSION = '0.461';
 
 ######################################################################
 
@@ -36,10 +39,10 @@ $VERSION = '0.46';
 
 =head2 Nonstandard Modules
 
-	CGI::Portable 0.46
-	CGI::Portable::AppStatic 0.46
-	CGI::MultiValuedHash 1.07
-	HTML::FormTemplate 2.01
+	CGI::Portable 0.461
+	CGI::Portable::AppStatic 0.461
+	CGI::MultiValuedHash 1.081
+	HTML::FormTemplate 2.021
 
 =cut
 
@@ -47,11 +50,11 @@ $VERSION = '0.46';
 
 use Fcntl qw(:DEFAULT :flock);
 use Symbol;
-use CGI::Portable 0.46;
-use CGI::Portable::AppStatic 0.46;
+use CGI::Portable 0.461;
+use CGI::Portable::AppStatic 0.461;
 @ISA = qw(CGI::Portable::AppStatic);
-use CGI::MultiValuedHash 1.07;
-use HTML::FormTemplate 2.01;
+use CGI::MultiValuedHash 1.081;
+use HTML::FormTemplate 2.021;
 
 ######################################################################
 
@@ -61,6 +64,7 @@ use HTML::FormTemplate 2.01;
 
 	#!/usr/bin/perl
 	use strict;
+	use warnings;
 
 	require CGI::Portable;
 	my $globals = CGI::Portable->new();
@@ -1009,16 +1013,21 @@ __END__
 
 =head1 AUTHOR
 
-Copyright (c) 1999-2001, Darren R. Duncan. All rights reserved. This module is
-free software; you can redistribute it and/or modify it under the same terms as
-Perl itself.  However, I do request that this copyright information remain
-attached to the file.  If you modify this module and redistribute a changed
-version then please attach a note listing the modifications.
+Copyright (c) 1999-2003, Darren R. Duncan.  All rights reserved.  This module
+is free software; you can redistribute it and/or modify it under the same terms
+as Perl itself.  However, I do request that this copyright information and
+credits remain attached to the file.  If you modify this module and
+redistribute a changed version then please attach a note listing the
+modifications.  This module is available "as-is" and the author can not be held
+accountable for any problems resulting from its use.
 
 I am always interested in knowing how my work helps others, so if you put this
-module to use in any of your own code then please send me the URL.  Also, if you
-make modifications to the module because it doesn't work the way you need, please
-send me a copy so that I can roll desirable changes into the main release.
+module to use in any of your own products or services then I would appreciate
+(but not require) it if you send me the website url for said product or
+service, so I know who you are.  Also, if you make non-proprietary changes to
+the module because it doesn't work the way you need, and you are willing to
+make these freely available, then please send me a copy so that I can roll
+desirable changes into the main release.
 
 Address comments, suggestions, and bug reports to B<perl@DarrenDuncan.net>.
 
