@@ -9,15 +9,18 @@ CGI::Portable::Request - Stores user input, makes self-referencing urls
 package CGI::Portable::Request;
 require 5.004;
 
-# Copyright (c) 1999-2001, Darren R. Duncan. All rights reserved. This module is
-# free software; you can redistribute it and/or modify it under the same terms as
-# Perl itself.  However, I do request that this copyright information remain
-# attached to the file.  If you modify this module and redistribute a changed
-# version then please attach a note listing the modifications.
+# Copyright (c) 1999-2003, Darren R. Duncan.  All rights reserved.  This module
+# is free software; you can redistribute it and/or modify it under the same terms
+# as Perl itself.  However, I do request that this copyright information and
+# credits remain attached to the file.  If you modify this module and
+# redistribute a changed version then please attach a note listing the
+# modifications.  This module is available "as-is" and the author can not be held
+# accountable for any problems resulting from its use.
 
 use strict;
+use warnings;
 use vars qw($VERSION);
-$VERSION = '0.47';
+$VERSION = '0.471';
 
 ######################################################################
 
@@ -33,15 +36,15 @@ $VERSION = '0.47';
 
 =head2 Nonstandard Modules
 
-	File::VirtualPath 1.0
-	CGI::MultiValuedHash 1.07
+	File::VirtualPath 1.011
+	CGI::MultiValuedHash 1.081
 
 =cut
 
 ######################################################################
 
-use File::VirtualPath 1.0;
-use CGI::MultiValuedHash 1.07;
+use File::VirtualPath 1.011;
+use CGI::MultiValuedHash 1.081;
 
 ######################################################################
 
@@ -326,7 +329,7 @@ sub clone {
 	$clone->{$KEY_URL_BASE} = $self->{$KEY_URL_BASE};
 	$clone->{$KEY_URL_PATH} = $self->{$KEY_URL_PATH}->clone();
 	$clone->{$KEY_URL_QUER} = $self->{$KEY_URL_QUER}->clone();
-	
+
 	return( $clone );
 }
 
@@ -1225,16 +1228,21 @@ __END__
 
 =head1 AUTHOR
 
-Copyright (c) 1999-2001, Darren R. Duncan. All rights reserved. This module is
-free software; you can redistribute it and/or modify it under the same terms as
-Perl itself.  However, I do request that this copyright information remain
-attached to the file.  If you modify this module and redistribute a changed
-version then please attach a note listing the modifications.
+Copyright (c) 1999-2003, Darren R. Duncan.  All rights reserved.  This module
+is free software; you can redistribute it and/or modify it under the same terms
+as Perl itself.  However, I do request that this copyright information and
+credits remain attached to the file.  If you modify this module and
+redistribute a changed version then please attach a note listing the
+modifications.  This module is available "as-is" and the author can not be held
+accountable for any problems resulting from its use.
 
 I am always interested in knowing how my work helps others, so if you put this
-module to use in any of your own code then please send me the URL.  Also, if you
-make modifications to the module because it doesn't work the way you need, please
-send me a copy so that I can roll desirable changes into the main release.
+module to use in any of your own products or services then I would appreciate
+(but not require) it if you send me the website url for said product or
+service, so I know who you are.  Also, if you make non-proprietary changes to
+the module because it doesn't work the way you need, and you are willing to
+make these freely available, then please send me a copy so that I can roll
+desirable changes into the main release.
 
 Address comments, suggestions, and bug reports to B<perl@DarrenDuncan.net>.
 
